@@ -5,7 +5,10 @@ Module defining the serialization method for sympy objects.
 import sympy
 
 from ._special_types import (
-    _SpecialTypeTags, to_hdf5_singledispatch, _value_serializer, add_type_tag
+    _SpecialTypeTags,
+    _value_serializer,
+    add_type_tag,
+    to_hdf5_singledispatch,
 )
 
 
